<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>AccountItem</name>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="40"/>
        <source>Sync successful</source>
        <translation>A szinkronizálás sikeres</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="41"/>
        <source>Network error</source>
        <translation>Hálózati hiba</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="42"/>
        <source>Server exception</source>
        <translation>Szerver kivétel</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountitem.cpp" line="43"/>
        <source>Storage full</source>
        <translation>A tárhely megtelt</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="223"/>
        <source>Local account</source>
        <translation>Helyi fiók</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dataManage/accountmanager.cpp" line="225"/>
        <source>Event types</source>
        <translation>Esemény típusok</translation>
    </message>
</context>
<context>
    <name>CColorPickerWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="77"/>
        <source>Color</source>
        <translation>Szín</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="90"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/colorWidget/colorpickerWidget.cpp" line="92"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Mentés</translation>
    </message>
</context>
<context>
    <name>CDayMonthView</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="33"/>
        <source>Monday</source>
        <translation>Hétfő</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="34"/>
        <source>Tuesday</source>
        <translation>Kedd</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="35"/>
        <source>Wednesday</source>
        <translation>Szerda</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="36"/>
        <source>Thursday</source>
        <translation>Csütörtök</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="37"/>
        <source>Friday</source>
        <translation>Péntek</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="38"/>
        <source>Saturday</source>
        <translation>Szombat</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="39"/>
        <source>Sunday</source>
        <translation>Vasárnap</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="112"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="113"/>
        <source>M</source>
        <translation>Hónap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="114"/>
        <source>D</source>
        <translation>Nap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daywindow.cpp" line="170"/>
        <source>Lunar</source>
        <translation>Hold naptár</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <location filename="../calendar-client/src/view/graphicsview.cpp" line="592"/>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
</context>
<context>
    <name>CMonthScheduleNumItem</name>
    <message>
        <location filename="../calendar-client/src/view/graphicsItem/cmonthschedulenumitem.cpp" line="80"/>
        <source>%1 more</source>
        <translation>%1 továbbiak</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthview.cpp" line="51"/>
        <source>New event</source>
        <translation>Új esemény</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthview.cpp" line="209"/>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="98"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
</context>
<context>
    <name>CMyScheduleView</name>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="267"/>
        <source>My Event</source>
        <translation>Eseményeim</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="308"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="312"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/myscheduleview.cpp" line="313"/>
        <source>Edit</source>
        <comment>button</comment>
        <translation>Szerkesztés</translation>
    </message>
</context>
<context>
    <name>CPushButton</name>
    <message>
        <location filename="../calendar-client/src/customWidget/cpushbutton.cpp" line="17"/>
        <source>New event type</source>
        <translation>Új esemény típusa</translation>
    </message>
</context>
<context>
    <name>CScheduleDlg</name>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="45"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="600"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="896"/>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="58"/>
        <source>Edit Event</source>
        <translation>Esemény szerkesztése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="256"/>
        <source>End time must be greater than start time</source>
        <translation>A befejezés időpontja csak a kezdés időpontja után lehetséges</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="257"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="481"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="510"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1108"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1143"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1397"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1401"/>
        <source>Never</source>
        <translation>Soha</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="482"/>
        <source>At time of event</source>
        <translation>Az esemény időpontjában</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="483"/>
        <source>15 minutes before</source>
        <translation>15 perccel előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="484"/>
        <source>30 minutes before</source>
        <translation>30 perccel előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="485"/>
        <source>1 hour before</source>
        <translation>1 órával előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="486"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="512"/>
        <source>1 day before</source>
        <translation>1 nappal előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="487"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="513"/>
        <source>2 days before</source>
        <translation>2 nappal előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="488"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="514"/>
        <source>1 week before</source>
        <translation>1 héttel előtte</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="511"/>
        <source>On start day (9:00 AM)</source>
        <translation>Esemény kezdete napján (De. 09:00)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="558"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="766"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1164"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1165"/>
        <source>time(s)</source>
        <translation>Időpont(ok)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="573"/>
        <source>Enter a name please</source>
        <translation>Kérjük adjon meg egy nevet</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="668"/>
        <source>The name can not only contain whitespaces</source>
        <translation>A név nem tartalmazhat csak szóközöket</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="724"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="846"/>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="729"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="881"/>
        <source>Description:</source>
        <translation>Leírás:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="734"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="918"/>
        <source>All Day:</source>
        <translation>Egész nap:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="739"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="984"/>
        <source>Starts:</source>
        <translation>Kezdés:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="744"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1025"/>
        <source>Ends:</source>
        <translation>Befejezés:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="749"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1065"/>
        <source>Remind Me:</source>
        <translation>Emlékeztessen:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="754"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1097"/>
        <source>Repeat:</source>
        <translation>Ismétlés:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="759"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1131"/>
        <source>End Repeat:</source>
        <translation>Ismétlés vége:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="815"/>
        <source>Calendar account:</source>
        <translation>Naptár fiók:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="816"/>
        <source>Calendar account</source>
        <translation>Naptár fiók</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="843"/>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="885"/>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="915"/>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="939"/>
        <source>Time:</source>
        <translation>Idő:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="940"/>
        <source>Time</source>
        <translation>Idő</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="947"/>
        <source>Solar</source>
        <translation>Nap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="948"/>
        <source>Lunar</source>
        <translation>Hold</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="981"/>
        <source>Starts</source>
        <translation>Kezdés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1022"/>
        <source>Ends</source>
        <translation>Befejezés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1067"/>
        <source>Remind Me</source>
        <translation>Emlékeztessen</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1094"/>
        <source>Repeat</source>
        <translation>Ismétlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1109"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1402"/>
        <source>Daily</source>
        <translation>Naponta</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1110"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1403"/>
        <source>Weekdays</source>
        <translation>Hétköznapokon</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1111"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1404"/>
        <source>Weekly</source>
        <translation>Hetente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1112"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1398"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1405"/>
        <source>Monthly</source>
        <translation>Havonta</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1113"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1399"/>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1406"/>
        <source>Yearly</source>
        <translation>Évente</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1133"/>
        <source>End Repeat</source>
        <translation>Ismétlés vége</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1144"/>
        <source>After</source>
        <translation>Utána</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1145"/>
        <source>On</source>
        <translation>Ekkor</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1215"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduledlg.cpp" line="1216"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Mentés</translation>
    </message>
</context>
<context>
    <name>CScheduleOperation</name>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="79"/>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>Az ismétlődő események valamennyiének &quot;egész nap&quot; állapotúnak kell lennie.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="80"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="97"/>
        <source>Do you want to change all occurrences?</source>
        <translation>Minden alkalmat módosítani szeretne?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="81"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="98"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="128"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="147"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="167"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="239"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="269"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="82"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="99"/>
        <source>Change All</source>
        <translation>Összes módosítása</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="96"/>
        <source>You are changing the repeating rule of this event.</source>
        <translation>Módosítja az esemény ismétlődési szabályát.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="126"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="145"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="165"/>
        <source>You are deleting an event.</source>
        <translation>Ön töröl egy eseményt.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="127"/>
        <source>Are you sure you want to delete this event?</source>
        <translation>Biztosan törli ezt az eseményt?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="129"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="146"/>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Törlöni szeretné az esemény összes előfordulását, vagy csak a kiválasztott eseményt?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="148"/>
        <source>Delete All</source>
        <translation>Összes törlése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="149"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="169"/>
        <source>Delete Only This Event</source>
        <translation>Csak ezen esemény törlése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="166"/>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Törölni szeretné ezt, és az esemény összes jövőbeli előfordulását, vagy csak a kiválasztott eseményt?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="168"/>
        <source>Delete All Future Events</source>
        <translation>Összes jövőbeli esemény törlése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="235"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="265"/>
        <source>You are changing a repeating event.</source>
        <translation>Ön egy ismétlődő eseményt módosít.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="237"/>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Csak az esemény ezen előfordulását akarja megváltoztatni, vagy az összes jövőbeni eseményt?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="240"/>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="241"/>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="271"/>
        <source>Only This Event</source>
        <translation>Csak ezen esemény</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="267"/>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Csak az esemény ezen előfordulását akarja megváltoztatni, vagy ezt és az összes jövőbeni eseményt?</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="270"/>
        <source>All Future Events</source>
        <translation>Összes jövőbeli esemény</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="382"/>
        <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
        <translation>Szökőhónap lett kiválasztva, ezért a holdnaptár szabályai fognak érvényesülni.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/scheduleTask/cscheduleoperation.cpp" line="383"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchDateItem</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="902"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="902"/>
        <source>M</source>
        <translation>Hónap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="902"/>
        <source>D</source>
        <translation>Nap</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchItem</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="42"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="43"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="267"/>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
</context>
<context>
    <name>CScheduleSearchView</name>
    <message>
        <location filename="../calendar-client/src/widget/schedulesearchview.cpp" line="645"/>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <location filename="../calendar-client/src/customWidget/scheduleview.cpp" line="314"/>
        <source>ALL DAY</source>
        <translation>Egész nap</translation>
    </message>
</context>
<context>
    <name>CSettingDialog</name>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="345"/>
        <source>Sunday</source>
        <translation>Vasárnap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="346"/>
        <source>Monday</source>
        <translation>Hétfő</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="347"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="366"/>
        <source>Use System Setting</source>
        <translation>Rendszerbeállítások használata</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="364"/>
        <source>24-hour clock</source>
        <translation>24 órás óra formátum</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="365"/>
        <source>12-hour clock</source>
        <translation>12 órás óra formátum</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="389"/>
        <source>import ICS file</source>
        <translation>ICS fájl importálása</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="403"/>
        <source>Manual</source>
        <translation>Manuális</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="404"/>
        <source>15 mins</source>
        <translation>15 perc</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="405"/>
        <source>30 mins</source>
        <translation>30 perc</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="406"/>
        <source>1 hour</source>
        <translation>1 óra</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="407"/>
        <source>24 hours</source>
        <translation>24 óra</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="418"/>
        <source>Sync Now</source>
        <translation>Szinkronizálás most</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="576"/>
        <source>Last sync</source>
        <translation>Utolsó szinkronizálás</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="770"/>
        <source>Please go to the &lt;a href=&apos;/&apos;&gt;Control Center&lt;/a&gt; to change system settings</source>
        <translation>Kérjük lépjen a &lt;a href=&apos;/&apos;&gt;Vezérlőközpontba&lt;/a&gt; a beállítások módosításához</translation>
    </message>
</context>
<context>
    <name>CTimeEdit</name>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="72"/>
        <source>(%1 mins)</source>
        <translation>(%1 perc)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="74"/>
        <source>(%1 hour)</source>
        <translation>(%1 óra)</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/timeedit.cpp" line="76"/>
        <source>(%1 hours)</source>
        <translation>(%1 óra)</translation>
    </message>
</context>
<context>
    <name>CTitleWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="30"/>
        <source>Y</source>
        <translation>Éves</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="42"/>
        <source>M</source>
        <translation>Havi</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="50"/>
        <source>W</source>
        <translation>Hét</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="58"/>
        <source>D</source>
        <translation>Napi</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="92"/>
        <location filename="../calendar-client/src/customWidget/ctitlewidget.cpp" line="93"/>
        <source>Search events and festivals</source>
        <translation>Események és fesztiválok keresése</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Sun</source>
        <translation>V.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Mon</source>
        <translation>H.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Tue</source>
        <translation>K.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Wed</source>
        <translation>Sze.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Thu</source>
        <translation>Cs.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Fri</source>
        <translation>P.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/cweekwidget.cpp" line="72"/>
        <source>Sat</source>
        <translation>Szo.</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="89"/>
        <source>Week</source>
        <translation>Heti</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="276"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
</context>
<context>
    <name>CYearScheduleView</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="268"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="271"/>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearscheduleview.cpp" line="288"/>
        <source>No event</source>
        <translation>Nincs esemény</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="616"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <location filename="../calendar-client/src/main.cpp" line="63"/>
        <source>Calendar</source>
        <translation>Naptár</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/main.cpp" line="66"/>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>A Naptár egy eszköz a dátumok megtekintésére, valamint egy intelligens napi tervező az élet minden dolgának ütemezéséhez.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="87"/>
        <source>Calendar</source>
        <translation>Naptár</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="356"/>
        <source>Manage</source>
        <translation>Kezelés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="363"/>
        <source>Privacy Policy</source>
        <translation>Adatvédelmi irányelvek</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="940"/>
        <source>Syncing...</source>
        <translation>Szinkronizálás...</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="950"/>
        <source>Sync successful</source>
        <translation>A szinkronizálás sikeres</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/calendarmainwindow.cpp" line="958"/>
        <source>Sync failed, please try later</source>
        <translation>A szinkronizálás sikertelen, kérjük próbálja később</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <location filename="../calendar-client/src/customWidget/scheduleRemindWidget.cpp" line="174"/>
        <source>All Day</source>
        <translation>Egész nap</translation>
    </message>
</context>
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation type="vanished">Munka</translation>
    </message>
    <message>
        <source>Life</source>
        <translation type="vanished">Magánélet</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="vanished">Egyéb</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Bezárás</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Egy nappal kezdés előtt</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Emlékeztessen holnap</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Emlékeztessen később</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation type="vanished">15 perc múlva</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation type="vanished">1 óra múlva</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation type="vanished">4 óra múlva</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Holnap</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Ütemezési emlékeztető</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1-től %2-ig</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Ma</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="47"/>
        <source>Edit</source>
        <translation>Szerkesztés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="48"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="49"/>
        <source>New event</source>
        <translation>Új esemény</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/view/draginfographicsview.cpp" line="737"/>
        <source>New Event</source>
        <translation>Új esemény</translation>
    </message>
</context>
<context>
    <name>JobTypeListView</name>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="142"/>
        <source>export</source>
        <translation>Exportálás</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="213"/>
        <source>import ICS file</source>
        <translation>ICS fájl importálása</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="401"/>
        <source>You are deleting an event type.</source>
        <translation>Ön töröl egy eseménytípust.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="402"/>
        <source>All events under this type will be deleted and cannot be recovered.</source>
        <translation>Az összes ilyen típusú esemény törlődik, és nem állítható helyre.</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="403"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/customWidget/jobtypelistview.cpp" line="404"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="96"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="127"/>
        <source>Manage calendar</source>
        <translation>Naptár kezelése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="112"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="131"/>
        <source>Event types</source>
        <translation>Esemény típusok</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="38"/>
        <source>Account settings</source>
        <translation>Felhasználói fiók beállítások</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="42"/>
        <source>Account</source>
        <translation>Felhasználói fiók</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="53"/>
        <source>Select items to be synced</source>
        <translation>Válassza ki a szinkronizálni kívánt elemeket</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="56"/>
        <source>Events</source>
        <translation>Események</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="63"/>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="146"/>
        <source>General settings</source>
        <translation>Általános beállítások</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="74"/>
        <source>Sync interval</source>
        <translation>Szinkronizálási időintervallum</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="104"/>
        <source>Calendar account</source>
        <translation>Naptár fiók</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="150"/>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="152"/>
        <source>First day of week</source>
        <translation>A hét első napja</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/settingdialog.cpp" line="153"/>
        <source>Time</source>
        <translation>Idő</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="612"/>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Ma</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="339"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="95"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="273"/>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Ma</translation>
    </message>
</context>
<context>
    <name>ScheduleTypeEditDlg</name>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="21"/>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="47"/>
        <source>New event type</source>
        <translation>Új esemény típusa</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="31"/>
        <source>Edit event type</source>
        <translation>Eseménytípus szerkesztése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="43"/>
        <source>Import ICS file</source>
        <translation>ICS fájl importálása</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="140"/>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="141"/>
        <source>Color:</source>
        <translation>Szín:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="145"/>
        <source>&lt;a href=&apos;https://wikipedia.org/wiki/ICalendar&apos;&gt;ICS&lt;/a&gt; File:</source>
        <translation>&lt;a href=&apos;https://wikipedia.org/wiki/ICalendar&apos;&gt;ICS&lt;/a&gt; Fájl:</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="156"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="157"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="205"/>
        <source>The name can not only contain whitespaces</source>
        <translation>A név nem tartalmazhat csak szóközöket</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/dialog/scheduletypeeditdlg.cpp" line="241"/>
        <source>Enter a name please</source>
        <translation>Kérjük adjon meg egy nevet</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="16"/>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="17"/>
        <source>Delete event</source>
        <translation>Esemény törlése</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="20"/>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="21"/>
        <source>Cut</source>
        <translation>Kivágás</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="22"/>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="25"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/shortcut.cpp" line="26"/>
        <source>Select all</source>
        <translation>Összes kijelölése</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <location filename="../calendar-client/src/widget/sidebarWidget/sidebarcalendarwidget.cpp" line="126"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/sidebarWidget/sidebarcalendarwidget.cpp" line="126"/>
        <source>M</source>
        <translation>Hónap</translation>
    </message>
</context>
<context>
    <name>TimeJumpDialog</name>
    <message>
        <location filename="../calendar-client/src/dialog/timejumpdialog.cpp" line="29"/>
        <source>Go</source>
        <comment>button</comment>
        <translation>Ugrás</translation>
    </message>
</context>
<context>
    <name>UserloginWidget</name>
    <message>
        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="48"/>
        <source>Sign In</source>
        <comment>button</comment>
        <translation>Bejelentkezés</translation>
    </message>
    <message>
        <location filename="../calendar-client/src/widget/settingWidget/userloginwidget.cpp" line="49"/>
        <source>Sign Out</source>
        <comment>button</comment>
        <translation>Kijelentkezés</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="925"/>
        <source>Y</source>
        <translation>Év</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="188"/>
        <location filename="../calendar-client/src/widget/dayWidget/daymonthview.cpp" line="337"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="93"/>
        <location filename="../calendar-client/src/widget/monthWidget/monthwindow.cpp" line="230"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="56"/>
        <location filename="../calendar-client/src/widget/weekWidget/weekwindow.cpp" line="271"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="262"/>
        <location filename="../calendar-client/src/widget/yearWidget/yearwindow.cpp" line="610"/>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Ma</translation>
    </message>
</context>
</TS>